@@ -54,9 +54,12 @@ def map_json(mapping_config, json_data, strict=False):
                 key, prop = get_loop_params(key)
                 list_result = []
                 list_json = walk_dict(json_data, key, strict)
-                for lj in list_json:
-                    if config in lj:
-                        list_result.append(lj[config])
+                if dict == type(list_json):
+                    list_result.append(list_json[config])
+                else:
+                    for lj in list_json:
+                        if config in lj:
+                            list_result.append(lj[config])
                 result[prop] = list_result
             else:
                 result[config] = json_data[key] if strict else json_data.get(key)
